@@ -350,10 +350,14 @@ define([
     /** class param 생성 */
     var GenerateClassInParamList = function(thatBlock) {
         var parentClassName = thatBlock.getState(STATE_parentClassName);
-        var classInParamStr = `(`;
-        classInParamStr += parentClassName;
-        classInParamStr += `):`;
-        return classInParamStr;
+        if (parentClassName != '') {
+            var classInParamStr = `(`;
+            classInParamStr += parentClassName;
+            classInParamStr += `):`;
+            return classInParamStr;
+        } else {
+            return ':';
+        }
     }
  
     /** def param 생성 */
@@ -384,7 +388,7 @@ define([
                 }
             };
          });
-         defInParamStr += `)`;
+         defInParamStr += `):`;
  
          return defInParamStr;
     }
@@ -474,7 +478,7 @@ define([
         var ifConditionListStr = ``;
         ifConditionList.forEach(( ifCondition, index ) => {
     
-            const { arg1, arg2, arg3, arg4, arg5, arg6 } = ifCondition;
+            const { arg1, arg2, arg3, arg4 } = ifCondition;
 
             if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
                 ifConditionListStr += `(`;
@@ -486,11 +490,6 @@ define([
                 ifConditionListStr += arg2;
             }
             ifConditionListStr += arg3;
-        
-            if ( arg4 !== 'none' ) {
-                ifConditionListStr += arg4;
-                ifConditionListStr += arg5;
-            }
                 
             if ( !(arg1 == '' && (arg2 == 'none' || arg2 == '') && arg3 == '')) {
                 ifConditionListStr += `)`;
@@ -498,7 +497,7 @@ define([
         
             if ( ifConditionList.length -1 !== index ) {
                 ifConditionListStr += '';
-                ifConditionListStr += arg6;
+                ifConditionListStr += arg4;
                 ifConditionListStr += '';
             }
         });
@@ -785,7 +784,8 @@ define([
              || blockType == BLOCK_CODELINE_TYPE.FINALLY 
              || blockType == BLOCK_CODELINE_TYPE.IMPORT
              || blockType == BLOCK_CODELINE_TYPE.LAMBDA
-             || blockType == BLOCK_CODELINE_TYPE.PROPERTY ) {
+             || blockType == BLOCK_CODELINE_TYPE.PROPERTY
+             || blockType == BLOCK_CODELINE_TYPE.RETURN ) {
         
              $(htmlDom).addClass(VP_BLOCK_BLOCKCODELINETYPE_CONTROL);
         } else if (blockType == BLOCK_CODELINE_TYPE.API) {
