@@ -1,16 +1,10 @@
 define([
     'jquery'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
     , 'nbextensions/visualpython/src/common/StringBuilder'
-
-    , '../../api.js'    
+   
     , '../../constData.js'
 
-], function ( $, vpCommon, vpConst, sb    
-
-             , api
-             , constData ){
+], function ( $, sb , constData ){
 
     const { VP_CLASS_STYLE_FLEX_ROW_CENTER
             , VP_CLASS_STYLE_FLEX_COLUMN_CENTER } = constData;
