@@ -1,17 +1,14 @@
 define([
     'jquery'
     , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
     , 'nbextensions/visualpython/src/common/StringBuilder'
-    , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
     , 'nbextensions/visualpython/src/common/component/vpTableLayoutVerticalSimple'
-    , 'nbextensions/visualpython/src/common/component/vpTableLayoutHorizontalSimple'
 
     , '../../api.js'    
     , '../../constData.js'
     , '../base/index.js'
 
-], function ( $, vpCommon, vpConst, sb, vpSuggestInputText, vpTableLayoutVerticalSimple, vpTableLayoutHorizontalSimple
+], function ( $, vpCommon, sb, vpTableLayoutVerticalSimple
 
               , api
               , constData
@@ -21,22 +18,16 @@ define([
             , UpdateOneArrayValueAndGet
             , DeleteOneArrayValueAndGet
         
-            , GenerateIfConditionList
-            , RenderInputRequiredColor
-            , RenderSelectRequiredColor } = api;
+            , GenerateIfCode } = api;
 
-    const { BLOCK_DIRECTION
-            , BLOCK_CODELINE_BTN_TYPE
-            , BLOCK_CODELINE_TYPE
+    const { BLOCK_CODELINE_TYPE
 
             , IF_BLOCK_CONDITION_TYPE
             , IF_BLOCK_SELECT_VALUE_ARG_TYPE
 
             , STR_COLON_SELECTED
             , STR_EMPTY
-            , STR_FOR
-            , STR_INPUT
-            , STR_SELECTED 
+
             , STR_DISABLED
             , STR_CLICK
             , STR_CHANGE
@@ -46,7 +37,6 @@ define([
             , STR_OPERATOR
 
             , STATE_ifConditionList
-            , STATE_elifConditionList
 
             , VP_CLASS_STYLE_FLEX_ROW
             , VP_CLASS_STYLE_FLEX_ROW_CENTER    
@@ -56,21 +46,6 @@ define([
             , VP_CLASS_STYLE_WIDTH_10PERCENT
             , VP_CLASS_STYLE_WIDTH_15PERCENT
             , VP_CLASS_STYLE_WIDTH_20PERCENT
-            , VP_CLASS_STYLE_WIDTH_25PERCENT
-            , VP_CLASS_STYLE_WIDTH_30PERCENT
-            , VP_CLASS_STYLE_WIDTH_35PERCENT
-            , VP_CLASS_STYLE_WIDTH_40PERCENT
-            , VP_CLASS_STYLE_WIDTH_45PERCENT
-            , VP_CLASS_STYLE_WIDTH_50PERCENT
-            , VP_CLASS_STYLE_WIDTH_55PERCENT
-            , VP_CLASS_STYLE_WIDTH_60PERCENT
-            , VP_CLASS_STYLE_WIDTH_65PERCENT
-            , VP_CLASS_STYLE_WIDTH_70PERCENT
-            , VP_CLASS_STYLE_WIDTH_75PERCENT
-            , VP_CLASS_STYLE_WIDTH_80PERCENT
-            , VP_CLASS_STYLE_WIDTH_85PERCENT
-            , VP_CLASS_STYLE_WIDTH_90PERCENT
-            , VP_CLASS_STYLE_WIDTH_95PERCENT
             , VP_CLASS_STYLE_WIDTH_100PERCENT
 
             , VP_CLASS_STYLE_BGCOLOR_C4C4C4
@@ -101,8 +76,7 @@ define([
             , MakeOptionDeleteButton
             , MakeOptionPlusButton
             , MakeVpSuggestInputText_apiblock
-            , MakeOptionInput
-            , MakeOptionSelectBox } = baseComponent;
+            , MakeOptionInput } = baseComponent;
 
             var InitIfBlockOption = function(thisBlock, optionPageSelector) {
                 var uuid = thisBlock.getUUID();
@@ -122,7 +96,7 @@ define([
                          */
                         $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid);
                         $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid, function(event) {
-                            // RenderInputRequiredColor(this);
+
                             var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
                             var ifConditionState = ifConditionListState[index];
                             var selectedValue = $(STR_COLON_SELECTED, this).val();
@@ -138,7 +112,7 @@ define([
                                 ifConditionList: ifConditionListState
                             });
 
-                            var ifConditionCode = GenerateIfConditionList(thisBlock);
+                            var ifConditionCode = GenerateIfCode(thisBlock);
                             thisBlock.writeCode(ifConditionCode);
                             blockContainerThis.renderBlockOptionTab();
                             event.stopPropagation();
@@ -150,7 +124,6 @@ define([
                          */
                         $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid);
                         $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid, function(event) {
-                            // RenderInputRequiredColor(this);
                             var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
                             var ifConditionState = ifConditionListState[index];
                             var selectedValue = $(STR_COLON_SELECTED, this).val();
@@ -166,7 +139,7 @@ define([
                                 ifConditionList: ifConditionListState
                             });
 
-                            var ifConditionCode = GenerateIfConditionList(thisBlock);
+                            var ifConditionCode = GenerateIfCode(thisBlock);
                             thisBlock.writeCode(ifConditionCode);
                             
                             blockContainerThis.renderBlockOptionTab();
@@ -192,19 +165,16 @@ define([
                                                 ...ifConditionState
                                                 , arg1: inputValue
                                             }
-                                            // RenderInputRequiredColor(this);
                                         } else if (i == 2) {
                                             updatedValue = {
                                                 ...ifConditionState
                                                 , arg2: inputValue 
                                             }
-                                            // RenderInputRequiredColor(this);
                                         } else if (i == 3) {
                                             updatedValue = {
                                                 ...ifConditionState
                                                 , arg3: inputValue 
                                             }
-                                            // RenderInputRequiredColor(this);
                                         }  else if (i == 4) {
                                             
                                             updatedValue = {
@@ -230,7 +200,6 @@ define([
                                                 ...ifConditionState
                                                 , arg6: inputValue
                                             }
-                                            // RenderInputRequiredColor(this);
                                         }
             
                                         ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
@@ -238,7 +207,7 @@ define([
                                             ifConditionList: ifConditionListState
                                         });
 
-                                        var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.IF);
+                                        var ifConditionCode = GenerateIfCode(thisBlock,BLOCK_CODELINE_TYPE.IF);
                                         thisBlock.writeCode(ifConditionCode);
 
                                         event.stopPropagation();
@@ -251,8 +220,6 @@ define([
                         /** If USER input 변경 이벤트 함수 바인딩 */
                         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid);
                         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid, function(event) {
-                 
-                            // RenderInputRequiredColor(this);
                    
                             var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
                             var ifConditionState = ifConditionListState[index];
@@ -269,7 +236,7 @@ define([
                                 ifConditionList: ifConditionListState
                             });
 
-                            var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.IF);
+                            var ifConditionCode = GenerateIfCode(thisBlock,BLOCK_CODELINE_TYPE.IF);
                             thisBlock.writeCode(ifConditionCode);
                             event.stopPropagation();
                         });
@@ -277,8 +244,6 @@ define([
         
                         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid);
                         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid, function(event) {
-                 
-                            // RenderInputRequiredColor(this);
                    
                             var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
                             var ifConditionState = ifConditionListState[index];
@@ -294,7 +259,7 @@ define([
                                 ifConditionList: ifConditionListState
                             });
 
-                            var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.IF);
+                            var ifConditionCode = GenerateIfCode(thisBlock,BLOCK_CODELINE_TYPE.IF);
                             thisBlock.writeCode(ifConditionCode);
                         
                             event.stopPropagation();
@@ -315,7 +280,7 @@ define([
                         thisBlock.setState({
                             ifConditionList: ifConditionListState
                         });
-                        var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.IF);
+                        var ifConditionCode = GenerateIfCode(thisBlock, BLOCK_CODELINE_TYPE.IF);
                         thisBlock.writeCode(ifConditionCode);
         
                         blockContainerThis.renderBlockOptionTab();
@@ -329,7 +294,7 @@ define([
                 $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid), function(event) {
         
                     var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
-                    thisBlock.addVariableIndex();
+  
                     var newCondition = {
                         arg1: ''
                         , arg2: ''
@@ -343,7 +308,7 @@ define([
                     thisBlock.setState({
                         ifConditionList: ifConditionListState
                     });
-                    var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.IF);
+                    var ifConditionCode = GenerateIfCode(thisBlock, BLOCK_CODELINE_TYPE.IF);
                     thisBlock.writeCode(ifConditionCode);
                     
                     blockContainerThis.renderBlockOptionTab();
@@ -355,7 +320,6 @@ define([
                 $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid), function(event) {
         
                     var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
-                    thisBlock.addVariableIndex();
                 
                     var newCondition = {
                         codeLine: ''
@@ -367,7 +331,7 @@ define([
                         ifConditionList: ifConditionListState
                     });
 
-                    var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.IF);
+                    var ifConditionCode = GenerateIfCode(thisBlock, BLOCK_CODELINE_TYPE.IF);
                     thisBlock.writeCode(ifConditionCode);
                     
                     blockContainerThis.renderBlockOptionTab();
@@ -384,7 +348,6 @@ define([
                             ...ifConditionState
                             , arg1: selectedValue 
                         }
-                        // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid, selectedValue);
                     } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2) {
                         if (selectedValue == 'none') {
                             selectedValue = STR_EMPTY;
@@ -393,13 +356,11 @@ define([
                             ...ifConditionState
                             , arg2: selectedValue 
                         }
-                        // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid, selectedValue);
                     } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3) {
                         updatedValue = {
                             ...ifConditionState
                             , arg3: selectedValue 
                         }
-                        // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid, selectedValue);
                     } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4) {
                
                         if (selectedValue == 'none') {
@@ -429,20 +390,18 @@ define([
                             ...ifConditionState
                             , arg6: selectedValue 
                         }
-                        // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid, selectedValue);
                     }
                     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
                     thisBlock.setState({
                         ifConditionList: ifConditionListState
                     });
-                    var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.IF);
+                    var ifConditionCode = GenerateIfCode(thisBlock, BLOCK_CODELINE_TYPE.IF);
                     thisBlock.writeCode(ifConditionCode);
    
                 }
         
                 /** If option 렌더링 */
                 var renderThisComponent = function() {
-                    // console.log('if render');
                     var optionContainerDom = MakeOptionContainer(thisBlock);
                     /* --------------------------- if ----------------------------- */
                     var loadedVariableNameList = blockContainerThis.getKernelLoadedVariableNameList();
@@ -616,11 +575,7 @@ define([
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).val(arg3);
                
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).val(arg5);
-                        // if (arg2 == 'none') {
-                        //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(STR_EMPTY);
-                        // } else {
-                        //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(arg2);
-                        // }
+
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(arg2);
                         if (arg4 == '') {
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).val(STR_EMPTY);
@@ -641,12 +596,6 @@ define([
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_1);
                         }
               
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid);
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid);
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid);
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid);
-        
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid);
                     });
 
                     return optionContainerDom;
