@@ -6,13 +6,21 @@ define([
     const { MapTypeToName
             , RenderHTMLDomColor
             , IsDefineBlockType
-            , IsControlBlockType } = api;
+            , IsControlBlockType
+            , GenerateDefCode } = api;
     const {  BLOCK_CODELINE_TYPE
             , BLOCK_DIRECTION
 
+            , STR_CLICK
+
             , VP_CLASS_PREFIX
             , VP_CLASS_APIBLOCK_MAIN    
-            , VP_CLASS_APIBLOCK_BOARD } = constData;  
+            , VP_CLASS_APIBLOCK_BOARD
+
+            , STR_EMPTY
+            , DEF_BLOCK_ARG6_TYPE
+
+            , STATE_defInParamList } = constData;  
 
     var CreateBlockBtn = function(blockContainerThis, type) { 
         this.blockContainerThis = blockContainerThis;
@@ -21,6 +29,7 @@ define([
         this.createBlockBtnDom = null;
         this.render();
         this.bindBtnDragEvent();
+        this.bindBtnClickEvent();
     }
 
     CreateBlockBtn.prototype.getBlockContainerThis = function() {
@@ -85,6 +94,34 @@ define([
         createBlockContainer.append(createBlockBtnDom);
     }
 
+    /**
+     * 메뉴 블럭 클릭 시 Board에 생성하는 이벤트
+     */
+    CreateBlockBtn.prototype.bindBtnClickEvent = function() {
+        var blockContainerThis = this.blockContainerThis;
+        var blockCodeLineType = this.getBlockType();
+        // var funcID = this.funcID;
+        // var naviInfo = getNavigationInfo(funcID);
+        $(this.createBlockBtnDom).on(STR_CLICK, function(event) {
+            event.stopPropagation();
+
+            /** board에 선택한 API List 블럭 생성 */
+            blockContainerThis.resetBlockList();
+
+            var isFirstBlock = false;
+            const blockList = blockContainerThis.getBlockList();
+            /** board에 블럭이 0개 일때
+             *  즉 블럭이 처음으로 생성되는 경우
+             */
+            if (blockList.length == 0) {
+                isFirstBlock = true;
+            }
+
+            var createdBlock_api = blockContainerThis.createBlock(blockCodeLineType, null, null, true, true);
+            blockContainerThis.resetBlockListAndRenderThisBlock(createdBlock_api);
+        });
+    }
+
     CreateBlockBtn.prototype.bindBtnDragEvent = function() {
         var thisBlockBtn = this;
         var createBlockDom = this.getBlockMainDom();
@@ -110,8 +147,8 @@ define([
                 /** shadow 블럭 생성 */
                 shadowBlock = blockContainerThis.createShadowBlock( blockCodeLineType);
 
-                /** height 길이 결정 */
-                blockContainerThis.reLoadBlockListLeftHolderHeight();
+                blockContainerThis.reLoadBlockListLeftHolderHeight();  
+                /** width 길이 결정 */
                 var clientRect  = thisBlockBtn.getBlockMainDomPosition();
                 width = clientRect.width;
             },
@@ -132,7 +169,7 @@ define([
              
                 ({ selectedBlock, selectedBlockDirection } = blockContainerThis.dragBlock(false, null, shadowBlock, 
                                                                                             null, selectedBlockDirection, currCursorX, currCursorY));
-                        
+        
             },
             stop: function() {
 
@@ -145,8 +182,8 @@ define([
                 /** Board에 생성된 Block에 연결한 경우 */
                 if (selectedBlock) {
                     newBlock = blockContainerThis.createBlock(blockCodeLineType );
+                    newBlock.apply();
                     selectedBlock.appendBlock(newBlock, selectedBlockDirection);
-                    newBlock.renderEditorScrollTop();
                     // console.log('Board에 생성된 Block에 연결한 경우');
 
                 /** Board에 생성된 Block에 연결하지 못한 경우 
@@ -163,40 +200,41 @@ define([
                         blockContainerThis.reNewContainerDom();
                         blockContainerThis.reRenderAllBlock_asc();
 
-                        newBlock = blockContainerThis.createNodeBlock();
-                        var createdBlock = blockContainerThis.createBlock( blockCodeLineType );
-                        newBlock.appendBlock(createdBlock, BLOCK_DIRECTION.DOWN);
-
-                        /** 최초 생성된 root 블럭 set root direction */
+                        newBlock = blockContainerThis.createBlock( blockCodeLineType, null, null, true);
+                        newBlock.apply();
                         newBlock.setDirection(BLOCK_DIRECTION.ROOT);
-                    
+                        blockContainerThis.addNodeBlock(newBlock);
+                        
 
                     /** `
                      * -----------------Board에 생성된 Block이 적어도 1개는 있을 때---------------------
                      */
                      /** 선택한 블럭이 있을때 */
-                    } else if (blockContainerThis.getSelectBlock() 
-                                && blockContainerThis.getSelectBlock().getBlockType() != BLOCK_CODELINE_TYPE.TEXT) {
-                        // console.log('선택한 블럭이 있을때');
+                    // } else if (blockContainerThis.getSelectBlock() 
+                    //             && blockContainerThis.getSelectBlock().getBlockType() != BLOCK_CODELINE_TYPE.TEXT) {
+                    //     // console.log('선택한 블럭이 있을때');
 
-                        newBlock = blockContainerThis.createBlock(blockCodeLineType );
-                        var findedNodeBlock = blockContainerThis.findNodeBlock();
-                        findedNodeBlock.getLastBlock_from_nodeBlockArea().appendBlock(newBlock, BLOCK_DIRECTION.DOWN);
+                    //     newBlock = blockContainerThis.createBlock(blockCodeLineType );
+                    //     var findedNodeBlock = blockContainerThis.findNodeBlock();
+                    //     findedNodeBlock.getLastBlock_from_thisBlockArea().appendBlock(newBlock, BLOCK_DIRECTION.DOWN);
                         
                     /** 선택한 블럭이 없을때 */
                     }  else {
                         // console.log('선택한 블럭이 없을때');
 
-                        newBlock = blockContainerThis.createNodeBlock();
-                        var createdBlock = blockContainerThis.createBlock( blockCodeLineType );
-                        newBlock.appendBlock(createdBlock, BLOCK_DIRECTION.DOWN);
+                        // newBlock = blockContainerThis.createNodeBlock();
+                        newBlock = blockContainerThis.createBlock( blockCodeLineType, null, null, true);
+                        newBlock.apply();
+                        blockContainerThis.addNodeBlock(newBlock);
 
                         var lastBottomBlock = blockContainerThis.getRootToLastBottomBlock();
                         lastBottomBlock.appendBlock(newBlock, BLOCK_DIRECTION.DOWN);
-
-                        newBlock.renderEditorScrollTop(true);
                     }
                 }
+ 
+                blockContainerThis.reRenderAllBlock_asc();
+                blockContainerThis.resetBlockListAndRenderThisBlock(newBlock);
+
                 blockContainerThis.stopDragBlock(false, newBlock); 
                 shadowBlock = null;
                 newBlock = null;
