@@ -185,7 +185,7 @@ define([
         /** 가운데 board 영역의 width */
         var boardPageRectWidth = NUM_API_BOARD_CENTER_PAGE_WIDTH;
         /** 오른쪽 option 영역의 width 계산 */
-        var optionPageRectWidth = mainPageRectWidthNum - buttonsPageRectWidth - boardPageRectWidth - 73;
+        var optionPageRectWidth = mainPageRectWidthNum - buttonsPageRectWidth - boardPageRectWidth - 68;
 
         /** visual python 전체의 width 렌더링 */
         $(vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_WRAPPER)).css(STR_WIDTH, mainPageRectWidth);
@@ -196,7 +196,7 @@ define([
         
         /** 오른쪽 option 영역의 max-width 렌더링*/
         // var optionPageRectWidth_maxWidth = mainPageRectWidthNum - buttonsPageRectWidth - 290 - 103;
-        var optionPageRectWidth_maxWidth = mainPageRectWidthNum - buttonsPageRectWidth - boardPageRectWidth - 8 - 73;
+        var optionPageRectWidth_maxWidth = mainPageRectWidthNum - buttonsPageRectWidth - boardPageRectWidth - 8 - 68;
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_MAX_WIDTH, optionPageRectWidth_maxWidth);
 
         /** 가운데 board 위 영역의 렌더링 */
@@ -306,11 +306,13 @@ define([
         /** Block Board page를 클릭했을 때 */
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD)).click(function(event) {
             /** Board에서 Board page를 클릭하고, block을 클릭하지 않았을 때 */
-            if ($(event.target).attr('class')
-                && ($(event.target).attr('class').indexOf('vp-apiblock-board-body') != -1 
-                    || $(event.target).attr('class').indexOf('vp-block-container') != -1 ) ) {
-                blockContainer.resetBlockList();
-                blockContainer.resetOptionPage();
+            if ($(event.target).hasClass('vp-apiblock-board-body') 
+                    || $(event.target).hasClass('vp-block-container')) {
+                blockContainer.checkModified();
+                blockContainer.checkSaveOptionPage(function(result) {
+                    blockContainer.resetBlockList();
+                    blockContainer.resetOptionPage();
+                });
             }
         });
 
@@ -360,6 +362,14 @@ define([
                 if (e.keyCode == ctrlKey || e.keyCode == cmdKey) {
                     ctrlDown = false;
                 }
+            }).click(function(e) {
+                // check modified
+                blockContainer.checkModified();
+            });
+
+            $(document).change($(vpCommon.wrapSelector('.vp-apiblock-option input')), function() {
+                // check modified
+                blockContainer.checkModified();
             });
 
             // DEPRECATED: ctrl+c / ctrl+v 삭제
@@ -393,7 +403,9 @@ define([
 
         /** +node 블럭 생성 버튼 클릭 함수 바인딩 */
         $(document).on(STR_CLICK, VP_ID_PREFIX + VP_ID_APIBLOCK_NODE_BLOCK_PLUS_BUTTON, function() {
-            blockContainer.createNodeBlock(true);
+            // blockContainer.createNodeBlock(true);
+            // +code 블럭 생성
+            blockContainer.createCodeBlock();
         });
 
         /** +text 블럭 생성 버튼 클릭 함수 바인딩 */
@@ -403,25 +415,40 @@ define([
 
         /** option page - preview 버튼 클릭 함수 바인딩 */
         $(document).on(STR_CLICK, VP_ID_PREFIX + VP_APIBLOCK_BOARD_OPTION_PREVIEW_BUTTON, function() {
-            if ($(this).hasClass('enabled')) {
+            var selectedBlock = blockContainer.getSelectBlock();
+            if (selectedBlock == null) {
                 blockContainer.hideOptionPreviewBox();
-                $(this).removeClass('enabled');
+                if ($(this).hasClass('enabled')) {
+                    blockContainer.resetOptionPage();
+                    $(this).removeClass('enabled');
+                } else {
+                    blockContainer.showOptionPageWithPreview();
+                    $(this).addClass('enabled');
+                }
             } else {
-                blockContainer.showOptionPreviewBox();
-                $(this).addClass('enabled');
+                if ($(this).hasClass('enabled')) {
+                    blockContainer.hideOptionPreviewBox();
+                    $(this).removeClass('enabled');
+                } else {
+                    blockContainer.showOptionPreviewBox();
+                    $(this).addClass('enabled');
+                }
             }
         });
 
         /** option page - cancel 버튼 클릭 함수 바인딩 */
         $(document).on(STR_CLICK, VP_ID_PREFIX + VP_APIBLOCK_BOARD_OPTION_CANCEL_BUTTON, function() {
-            blockContainer.resetBlockList();
-            blockContainer.resetOptionPage();
+            blockContainer.cancelBlock();
         });
 
         /** option page - apply 버튼 클릭 함수 바인딩 */
         $(document).on(STR_CLICK, VP_ID_PREFIX + VP_APIBLOCK_BOARD_OPTION_APPLY_BUTTON, function() {
-            // TODO:
-            
+            // if disabled, do nothing
+            if ($(this).hasClass('disabled')) {
+                return;
+            }
+
+            blockContainer.applyBlock();
         });
 
         /**
@@ -557,8 +584,10 @@ define([
         });
 
         $(document).on('click', function(evt) {
-            // close block menu
-            $(vpCommon.wrapSelector(vpCommon.formatString('#{0}', VP_ID_APIBLOCK_MENU_BOX))).hide();
+            if (evt.target.id != 'vp_apiblock_menu_box') {
+                // close block menu
+                $(vpCommon.wrapSelector(vpCommon.formatString('#{0}', VP_ID_APIBLOCK_MENU_BOX))).hide();
+            }
         });
 
         ControlToggleInput();
