@@ -6,8 +6,9 @@ define([
     , 'nbextensions/visualpython/src/common/StringBuilder'
     , 'nbextensions/visualpython/src/common/vpFuncJS'
     , 'nbextensions/visualpython/src/pandas/common/commonPandas'
+    , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
     , 'nbextensions/visualpython/src/pandas/common/pandasGenerator'
-], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, pdGen) {
+], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, vpSuggestInputText, pdGen) {
     // 옵션 속성
     const funcOptProp = {
         stepCount : 1
@@ -88,10 +89,9 @@ define([
      */
     PandasPackage.prototype.initHtml = function() {
         this.showFunctionTitle();
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
 
         this.bindOptions();
-
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
     }
 
     /**
@@ -106,11 +106,22 @@ define([
      */
     PandasPackage.prototype.bindOptions = function() {
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
         // if it has no additional options, remove that box
         if (this.package.variable == undefined || this.package.variable.length <= 0) {
             $(this.wrapSelector('#vp_optionBox')).closest('div.vp-accordion-container').remove();
         }
+
+        // aggregation types suggest input tag
+        var aggTypesTag = new vpSuggestInputText.vpSuggestInputText();
+        aggTypesTag.setComponentID('i1');
+        aggTypesTag.addClass('vp-input');
+        aggTypesTag.setSuggestList(function() { return [ "'sum'", "'max'", "'min'", "'mean'", "'median'", "'std'", "'count'", "'quantile'" ]; });
+        aggTypesTag.setNormalFilter(false);
+        aggTypesTag.setValue($(this.wrapSelector('#i1')).val());
+        $(this.wrapSelector('#i1')).replaceWith(function() {
+            return aggTypesTag.toTagString();
+        });
     };
 
     /**
@@ -118,8 +129,6 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return "BREAK_RUN";
-        
         var sbCode = new sb.StringBuilder();
         
         // 코드 생성
