@@ -52,7 +52,9 @@ define([
                                              style='margin-left: 10px;'>Save</button>`);
             var cancelFileDataBtn = $(`<button class='fileNavigationPage-btn-cabcelVisualPython'
                                                style='margin-left: 10px;'>Cancel</button>`);
-            var saveFileDataInput = $(`<input id='vp-fileNavigation' type='text' placeholder='Input file name'></input>`);
+            var saveFileDataInput = $(`<input id='vp-fileNavigation' type='text' placeholder='Input file name' />`);
+            var saveFileDataInput = $(vpCommon.formatString('<input id="{0}" type="text" placeholder="{1}" value="{2}" />'
+                                                            , 'vp=fileNavigation', 'Input file name', fileNavigationState.getVisualPythonFileName()));
             $('.fileNavigationPage-button').append(saveFileDataInput);
             $('.fileNavigationPage-button').append(saveFileDataBtn);
             $('.fileNavigationPage-button').append(cancelFileDataBtn);
