@@ -88,10 +88,9 @@ define([
      */
     PandasPackage.prototype.initHtml = function() {
         this.showFunctionTitle();
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
 
         this.bindOptions();
-
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
     }
 
     /**
@@ -105,12 +104,21 @@ define([
      * Pandas 기본 패키지 바인딩
      */
     PandasPackage.prototype.bindOptions = function() {
+        var that = this;
+        
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
         // if it has no additional options, remove that box
         if (this.package.variable == undefined || this.package.variable.length <= 0) {
             $(this.wrapSelector('#vp_optionBox')).closest('div.vp-accordion-container').remove();
         }
+
+        // on dataframe change
+        $(document).on('select_suggestvalue change', this.wrapSelector('#i0'), function() {
+            // dataframe columns search
+            pdGen.vp_bindColumnSource(that, this, ['level']);
+        });
+
     };
 
     /**
@@ -118,7 +126,6 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
         
