@@ -106,7 +106,7 @@ define([
      */
     PandasPackage.prototype.bindOptions = function() {
         // HTML 구성
-        // pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        // pdGen.vp_showInterface(this);
         this.tagGenerator = new tagGen.TagGenerator(this, libPandas._PANDAS_FUNCTION[funcOptProp.libID]);
         this.tagGenerator.generateTags();
         // if it has no additional options, remove that box
@@ -120,15 +120,9 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
         
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            sbCode.appendLine(prefixCode);
-        }
 
         // 코드 생성
         var result = ""; // TODO: pdGen.vp_codeGenerator(this.uuid, this.package);
@@ -138,12 +132,6 @@ define([
         // cell metadata 작성하기
         // pdGen.vp_setCellMetadata(_VP_CODEMD);
         
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            sbCode.appendLine('');
-            sbCode.append(postfix);
-        }
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
