@@ -105,11 +105,24 @@ define([
      * Pandas 기본 패키지 바인딩
      */
     PandasPackage.prototype.bindOptions = function() {
+        var that = this;
+
+        // df1 event
+        // on dataframe change
+        $(document).on('change', this.wrapSelector('#i0'), function() {
+            pdGen.vp_bindColumnSource(that, this, ['left_on']);
+        });
+
+        $(document).on('change', this.wrapSelector('#i1'), function() {
+            pdGen.vp_bindColumnSource(that, this, ['right_on']);
+        });
+
+
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
         // if it has no additional options, remove that box
         if (this.package.variable == undefined || this.package.variable.length <= 0) {
-            $(this.wrapSelector('#vp_optionBox')).closest('div.vp-pandas-block').remove();
+            $(this.wrapSelector('#vp_optionBox')).closest('div.vp-accordion-container').remove();
         }
     };
 
@@ -118,15 +131,9 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
         
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            sbCode.appendLine(prefixCode);
-        }
 
         // 코드 생성
         var result = pdGen.vp_codeGenerator(this.uuid, this.package);
@@ -136,12 +143,6 @@ define([
         // cell metadata 작성하기
         // pdGen.vp_setCellMetadata(_VP_CODEMD);
         
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            sbCode.appendLine('');
-            sbCode.append(postfix);
-        }
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
