@@ -8,8 +8,8 @@ define([
     , 'nbextensions/visualpython/src/pandas/common/commonPandas'
     , 'nbextensions/visualpython/src/pandas/common/pandasGenerator'
     , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
-    , 'nbextensions/visualpython/src/common/vpDataSelector'
-], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, pdGen, vpSuggestInputText, vpDataSelector) {
+    , 'nbextensions/visualpython/src/common/vpSubsetEditor'
+], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, pdGen, vpSuggestInputText, vpSubsetEditor) {
     // 옵션 속성
     const funcOptProp = {
         stepCount : 1
@@ -118,7 +118,7 @@ define([
         this.bindCmapSelector();
         this.bindOptionDivider(14);
 
-        this.dataSelector = new vpDataSelector(this, "i0");
+        this.subsetEditor = new vpSubsetEditor(this, "i0");
 
     }
 
