@@ -124,7 +124,7 @@ define([
         var that = this;
 
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
 
         // 파일 네비게이션 버튼 추가
         $(this.fileResultState.pathInputId).parent().html(
@@ -163,27 +163,15 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
         
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            sbCode.appendLine(prefixCode);
-        }
 
         // 코드 생성
         var result = pdGen.vp_codeGenerator(this.uuid, this.package);
         if (result == null) return "BREAK_RUN"; // 코드 생성 중 오류 발생
         sbCode.append(result);
 
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            sbCode.appendLine('');
-            sbCode.append(postfix);
-        }
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
